import { Identifiable, InternshipType } from "@/data";
import { Transformer } from "@/serialization";

export interface InternshipTypeDTO extends Identifiable {
    label: string;
    labelEng: string;
    description?: string;
    descriptionEng?: string;
}

export const internshipTypeDtoTransformer: Transformer<InternshipTypeDTO, InternshipType> = {
    transform(subject: InternshipTypeDTO, context?: unknown): InternshipType {
        return {
            id: subject.id,
            label: {
                pl: subject.label,
                en: subject.labelEng
            },
            description: subject.description ? {
                pl: subject.description,
                en: subject.descriptionEng || ""
            } : undefined
        }
    },
    reverseTransform(subject: InternshipType, context?: unknown): InternshipTypeDTO {
        return {
            id: subject.id,
            label: subject.label.pl,
            labelEng: subject.label.en,
            description: subject.description?.pl || undefined,
            descriptionEng: subject.description?.en || undefined,
        }
    },
}
