import { Button, StepProps } from "@material-ui/core";
import { route } from "@/routing";
import { Link as RouterLink } from "react-router-dom";
import { Actions, Step } from "@/components";
import React, { useMemo } from "react";
import { useTranslation } from "react-i18next";
import { getMissingStudentData, Student } from "@/data";
import { useSelector } from "react-redux";
import { AppState } from "@/state/reducer";
import { useDeadlines } from "@/hooks";
import { AccountDetails } from "mdi-material-ui";

export const StudentStep = (props: StepProps) => {
    const { t } = useTranslation();
    const student = useSelector<AppState, Student | null>(state => state.student);
    const missingStudentData = useMemo(() => student ? getMissingStudentData(student) : [], [student]);
    const deadlines = useDeadlines();

    return <Step {...props} label={ t('steps.personal-data.header') } completed={ missingStudentData.length === 0 } until={ deadlines.personalData }>
        { missingStudentData.length > 0 ? <>
            <p>{ t('steps.personal-data.info') }</p>

            <ul>
                { missingStudentData.map(field => <li key={ field }>{ t(`student.${ field }`) }</li>) }
            </ul>

            <Button to={ route("user_fill") } variant="contained" color="primary" component={ RouterLink }>
                { t('steps.personal-data.actions.form') }
            </Button>
        </> : <>
            <p>{ t('steps.personal-data.all-filled') }</p>
            <Actions>
                <Button to={ route("user_profile") } variant="outlined" color="primary" component={ RouterLink } startIcon={ <AccountDetails /> }>
                    { t('steps.personal-data.actions.info') }
                </Button>
            </Actions>
        </> }
    </Step>
}
